@@ -67,6 +67,7 @@ class NicePrint:
           file['filesize'],
           file['source'],
           os.path.split(file['path'])[1],
+          file['url'],
           file['tags'],
         ] for file in analysis['files']
       ]
@@ -78,6 +79,7 @@ class NicePrint:
           'filesize (Gigabytes)',
           'source',
           'name',
+          'path'
           'tags',
         ],
         numalign='right',
